==> tecfy_basic_package-0.1.35.tar.gz: lib/views/components/checkbox.dart <==
part of tecfy_basic_package;

class AppCheckBox extends StatefulWidget {
  final String label;
  final bool initalValue;
  final bool isFullrow;
  final void Function(bool) onChanged;
  AppCheckBox(
      {this.label, this.initalValue, this.onChanged, this.isFullrow = false});
  @override
  _AppCheckBoxState createState() => _AppCheckBoxState();
}

class _AppCheckBoxState extends State<AppCheckBox> {
  bool _value;
  bool _classValue;
  @override
  void initState() {
    _classValue = widget.initalValue;
    _value = widget.initalValue ?? false;

    super.initState();
    if (widget.initalValue == null) valueChanged(false);
  }

  valueChanged(v) {
    _value = v;
    setState(() {});
    if (widget.onChanged != null)
      widget.onChanged(
          _value); // change the default value to be [false] when it's null
  }

  @override
  Widget build(BuildContext context) {
    if (widget.initalValue != _classValue) {
      _classValue = widget.initalValue;
      _value = widget.initalValue ?? false;
    }
    return MaterialButton(
        onPressed: () => valueChanged(!_value),
        child: Row(
          children: <Widget>[
            Checkbox(
              value: _value,
              onChanged: valueChanged,
            ),
            widget.isFullrow
                ? Expanded(
                    child: Text(
                    widget.label,
                    maxLines: 3,
                    softWrap: true,
                  ))
                : Text(widget.label)
          ],
        ));
  }
}

==> tecfy_basic_package-1.0.0.tar.gz: lib/views/components/checkbox.dart <==
part of tecfy_basic_package;

class AppCheckBox extends StatefulWidget {
  final String label;
  final bool? initalValue;
  final bool isFullrow;
  final void Function(bool)? onChanged;
  AppCheckBox(
      {required this.label,
      this.initalValue,
      this.onChanged,
      this.isFullrow = false});
  @override
  _AppCheckBoxState createState() => _AppCheckBoxState();
}

class _AppCheckBoxState extends State<AppCheckBox> {
  bool _value = false;
  bool? _classValue;
  @override
  void initState() {
    _classValue = widget.initalValue;
    _value = widget.initalValue ?? false;

    super.initState();
    if (widget.initalValue == null) valueChanged(false);
  }

  valueChanged(v) {
    _value = v;
    setState(() {});
    if (widget.onChanged != null)
      widget.onChanged?.call(
          _value); // change the default value to be [false] when it's null
  }

  @override
  Widget build(BuildContext context) {
    if (widget.initalValue != _classValue) {
      _classValue = widget.initalValue;
      _value = widget.initalValue ?? false;
    }
    return MaterialButton(
        onPressed: () => valueChanged(!_value),
        child: Row(
          children: <Widget>[
            Checkbox(
              value: _value,
              onChanged: valueChanged,
            ),
            widget.isFullrow
                ? Expanded(
                    child: Text(
                    widget.label,
                    maxLines: 3,
                    softWrap: true,
                  ))
                : Text(widget.label)
          ],
        ));
  }
}
